|Build Status|

A collection of common pynt tasks
=================================

`Raghunandan Rao <https://github.com/rags>`__

Contributors/Contributing
-------------------------

-  Ivan Ven Osdel

If you want to make changes the repo is at
https://github.com/rags/pynt-contrib. You will need
`pytest <http://www.pytest.org>`__ to run the tests

.. code:: bash

    $ ./b t

It will be great if you can raise a `pull
request <https://help.github.com/articles/using-pull-requests>`__ once
you are done.

*If you find any bugs or need new features please raise a ticket in the
`issues section <https://github.com/rags/pynt-contrib/issues>`__ of the
github repo.*

License
-------

pynt-contrib is licensed under a `MIT
license <http://opensource.org/licenses/MIT>`__

.. |Build Status| image:: https://travis-ci.org/rags/pynt.png?branch=master
   :target: https://travis-ci.org/rags/pynt
